pub type JmpBufStruct = SigJmpBufFields;Expand description
This is the type you use to allocate a JmpBuf on the stack. (Glibc puns the two.)
Aliased Type
pub struct JmpBufStruct { /* private fields */ }pub type JmpBufStruct = SigJmpBufFields;This is the type you use to allocate a JmpBuf on the stack. (Glibc puns the two.)
pub struct JmpBufStruct { /* private fields */ }