pub type SigJmpBufStruct = SigJmpBufFields;Expand description
This is the type you use to allocate a SigJmpBuf on the stack.
Aliased Type
pub struct SigJmpBufStruct { /* private fields */ }pub type SigJmpBufStruct = SigJmpBufFields;This is the type you use to allocate a SigJmpBuf on the stack.
pub struct SigJmpBufStruct { /* private fields */ }